@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.9 2003/07/20 14:44:37 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.10 2003/08/28 06:13:25 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -87,6 +87,7 @@ void do_child(int unix_fd, int inet_fd)
 	for (;;)
 	{
 		int connection_reuse = 1;
+		int ssl_request = 0;
 
 		/* perform accept() */
 		frontend = do_accept(unix_fd, inet_fd);
@@ -100,6 +101,7 @@ void do_child(int unix_fd, int inet_fd)
 		unset_nonblock(frontend->fd);
 
 		/* read the startup packet */
+	retry_startup:
 		sp = read_startup_packet(frontend);
 		if (sp == NULL)
 		{
@@ -108,6 +110,24 @@ void do_child(int unix_fd, int inet_fd)
 			pool_close(frontend);
 			continue;
 		}
+		if (ntohl(sp->protoVersion) == 0x04D2162F)
+		{
+			/* SSL not supported */
+			pool_debug("SSLRequest: sent N; retry startup");
+			if (ssl_request)
+			{
+				pool_close(frontend);
+				continue;
+			}
+
+			/*
+			 * say to the frontend "we do not suppport SSL"
+			 * note that this is not a NOTICE response despite it's a 'N'!
+			 */
+			pool_write_and_flush(frontend, "N", 1);
+			ssl_request = 1;
+			goto retry_startup;
+		}
 
 		/*
 		 * if there's no connection associated with user and database,
