@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.3 2003/06/26 05:52:40 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_process_query.c,v 1.4 2003/07/20 14:44:37 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -31,11 +31,9 @@
 #include <sys/time.h>
 #endif
 
+#include <stdlib.h>
 #include <unistd.h>
 
-#include "server/postgres_fe.h"
-#include "server/libpq/pqcomm.h"
-
 #include "pool.h"
 
 static POOL_STATUS NotificationResponse(POOL_CONNECTION *frontend, 
@@ -45,7 +43,7 @@ static POOL_STATUS Query(POOL_CONNECTION *frontend,
 						 POOL_CONNECTION *backend);
 
 static POOL_STATUS ReadyForQuery(POOL_CONNECTION *frontend, 
-								 POOL_CONNECTION *backend, bool send_ready);
+								 POOL_CONNECTION *backend, int send_ready);
 
 static POOL_STATUS CompleteCommandResponse(POOL_CONNECTION *frontend, 
 										   POOL_CONNECTION *backend);
@@ -78,11 +76,11 @@ static int RowDescription(POOL_CONNECTION *frontend,
 
 static POOL_STATUS AsciiRow(POOL_CONNECTION *frontend, 
 							POOL_CONNECTION *backend,
-							int16 num_fields);
+							short num_fields);
 
 static POOL_STATUS BinaryRow(POOL_CONNECTION *frontend, 
 							 POOL_CONNECTION *backend,
-							 int16 num_fields);
+							 short num_fields);
 
 static POOL_STATUS FunctionCall(POOL_CONNECTION *frontend, 
 								POOL_CONNECTION *backend);
@@ -108,7 +106,7 @@ POOL_STATUS pool_process_query(POOL_CONNECTION *frontend,
 
 	if (connection_reuse)
 	{
-		status = ReadyForQuery(frontend, backend, false);
+		status = ReadyForQuery(frontend, backend, 0);
 		if (status != POOL_CONTINUE)
 			return status;
 	}
@@ -264,7 +262,7 @@ POOL_STATUS pool_process_query(POOL_CONNECTION *frontend,
 
 			case 'Z':
 				/* Ready for query */
-				status = ReadyForQuery(frontend, backend, true);
+				status = ReadyForQuery(frontend, backend, 1);
 				break;
 				
 			default:
@@ -299,7 +297,7 @@ static POOL_STATUS Query(POOL_CONNECTION *frontend,
 }
 
 static POOL_STATUS ReadyForQuery(POOL_CONNECTION *frontend, 
-								 POOL_CONNECTION *backend, bool send_ready)
+								 POOL_CONNECTION *backend, int send_ready)
 {
 	char kind;
 
@@ -338,18 +336,18 @@ static POOL_STATUS CompleteCommandResponse(POOL_CONNECTION *frontend,
 static int RowDescription(POOL_CONNECTION *frontend, 
 						  POOL_CONNECTION *backend)
 {
-	int16 num_fields;
-	int32 oid, mod;
-	int16 size;
+	short num_fields;
+	int oid, mod;
+	short size;
 	char *string;
 	int len;
 	int i;
 
 /* # of fields (could be 0) */
-	pool_read(backend, &num_fields, sizeof(int16));
+	pool_read(backend, &num_fields, sizeof(short));
 /* forward it to the frontend */
 	pool_write(frontend, "T", 1);
-	pool_write(frontend, &num_fields, sizeof(int16));
+	pool_write(frontend, &num_fields, sizeof(short));
 
 	num_fields = htons(num_fields);
 	for (i = 0;i<num_fields;i++)
@@ -362,16 +360,16 @@ static int RowDescription(POOL_CONNECTION *frontend,
 		pool_write(frontend, string, len);
 
 		/* oid */
-		pool_read(backend, &oid, sizeof(int32));
-		pool_write(frontend, &oid, sizeof(int32));
+		pool_read(backend, &oid, sizeof(int));
+		pool_write(frontend, &oid, sizeof(int));
 
 		/* size */
-		pool_read(backend, &size, sizeof(int16));
-		pool_write(frontend, &size, sizeof(int16));
+		pool_read(backend, &size, sizeof(short));
+		pool_write(frontend, &size, sizeof(short));
 
 		/* modifier */
-		pool_read(backend, &mod, sizeof(int32));
-		pool_write(frontend, &mod, sizeof(int32));
+		pool_read(backend, &mod, sizeof(int));
+		pool_write(frontend, &mod, sizeof(int));
 	}
 
 	if (pool_flush(frontend) < 0)
@@ -384,13 +382,13 @@ static int RowDescription(POOL_CONNECTION *frontend,
 
 static POOL_STATUS AsciiRow(POOL_CONNECTION *frontend, 
 							POOL_CONNECTION *backend,
-							int16 num_fields)
+							short num_fields)
 {
-	static int8 nullmap[8192];
+	static char nullmap[8192];
 	int nbytes;
 	int i;
-	uint8 mask;
-	int32 size;
+	unsigned char mask;
+	int size;
 	char *buf;
 	char msgbuf[1024];
 
@@ -419,10 +417,10 @@ static POOL_STATUS AsciiRow(POOL_CONNECTION *frontend,
 		if (mask & nullmap[i/8])
 		{
 			/* field size */
-			if (pool_read(backend, &size, sizeof(int32)) < 0)
+			if (pool_read(backend, &size, sizeof(int)) < 0)
 				return POOL_END;
 
-			pool_write(frontend, &size, sizeof(int32));
+			pool_write(frontend, &size, sizeof(int));
 			size = htonl(size) - 4;
 			buf = malloc(size);
 			if (buf == NULL)
@@ -452,13 +450,13 @@ static POOL_STATUS AsciiRow(POOL_CONNECTION *frontend,
 
 static POOL_STATUS BinaryRow(POOL_CONNECTION *frontend, 
 							 POOL_CONNECTION *backend,
-							 int16 num_fields)
+							 short num_fields)
 {
-	static int8 nullmap[8192];
+	static char nullmap[8192];
 	int nbytes;
 	int i;
-	uint8 mask;
-	int32 size;
+	unsigned char mask;
+	int size;
 	char *buf;
 
 	pool_write(frontend, "B", 1);
@@ -486,8 +484,8 @@ static POOL_STATUS BinaryRow(POOL_CONNECTION *frontend,
 		if (mask & nullmap[i/8])
 		{
 			/* field size */
-			pool_read(backend, &size, sizeof(int32));
-			pool_write(frontend, &size, sizeof(int32));
+			pool_read(backend, &size, sizeof(int));
+			pool_write(frontend, &size, sizeof(int));
 			size = htonl(size);
 			buf = malloc(size);
 			if (buf == NULL)
